@@ -27,7 +27,7 @@
 #include <errno.h>
 
 #include <glib/gi18n.h>
-#include <glib/goption.h>
+#include <glib.h>
 #include <gtk/gtk.h>
 #include <unique/uniqueapp.h>
 
