@@ -67,8 +67,9 @@ on_adjustment_value_changed (GtkAdjustment *adjustment,
         gdouble volume;
 
         volume = gtk_adjustment_get_value (adjustment);
-        gvc_mixer_stream_change_volume (icon->priv->mixer_stream,
-                                        (guint)volume);
+
+        gvc_mixer_stream_set_volume(icon->priv->mixer_stream,
+                                    (pa_volume_t) volume );
 }
 
 static gboolean
@@ -155,7 +156,7 @@ popup_dock (GvcStreamStatusIcon *icon,
 
         if (gdk_pointer_grab (icon->priv->dock->window, TRUE,
                               GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
-                              GDK_POINTER_MOTION_MASK, NULL, NULL,
+                              GDK_POINTER_MOTION_MASK | GDK_SCROLL_MASK, NULL, NULL,
                               time)
             != GDK_GRAB_SUCCESS) {
                 gtk_grab_remove (icon->priv->dock);
@@ -372,6 +373,16 @@ on_dock_key_release (GtkWidget           *widget,
         return TRUE;
 }
 
+static gboolean
+on_dock_scroll_event (GtkWidget           *widget,
+                      GdkEventScroll      *event,
+                      GvcStreamStatusIcon *icon)
+{
+        /* Forward event to the status icon */
+        on_status_icon_scroll_event (NULL, event, icon);
+        return TRUE;
+}
+
 static void
 update_icon (GvcStreamStatusIcon *icon)
 {
@@ -637,6 +648,10 @@ gvc_stream_status_icon_constructor (GType                  type,
                           "key-release-event",
                           G_CALLBACK (on_dock_key_release),
                           icon);
+        g_signal_connect (icon->priv->dock,
+                          "scroll-event",
+                          G_CALLBACK (on_dock_scroll_event),
+                          icon);
         g_signal_connect (icon->priv->dock,
                           "grab-notify",
                           G_CALLBACK (on_dock_grab_notify),
